@@ -4,7 +4,7 @@ UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 8
-_modified_time = 1394857015.870179
+_modified_time = 1397320108.687188
 _enable_loop = True
 _template_filename = '/MyWork/Projects/PyCK/pyck/forms/templates/form_as_table.mako'
 _template_uri = 'form_as_table.mako'
@@ -42,7 +42,7 @@ def render_body(context,**pageargs):
         # SOURCE LINE 12
         if include_table_tag:
             # SOURCE LINE 13
-            __M_writer(u'<table>\n')
+            __M_writer(u'<table class="table table-striped table-hover">\n')
         # SOURCE LINE 15
         if form._use_csrf_protection:
             # SOURCE LINE 16
